Summary: Library that implements an embeddable SQL database engine
Name: sqlite
Version: 3.7.2
Release: 1
License: Public Domain
Group: 	Applications/Databases
URL: http://www.sqlite.org/
Source0: http://www.sqlite.org/%{name}-%{version}.tar.gz
Obsoletes: sqlite3 sqlite3-devel
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: make, readline-devel >= 5.2
Requires: readline >= 5.2

%description
SQLite is a C library that implements an embeddable SQL database engine.
Programs that link with the SQLite library can have SQL database access
without running a separate RDBMS process. The distribution comes with a
standalone command-line access program (sqlite) that can be used to
administer an SQLite database and which serves as an example of how to
use the SQLite library.

The library is available as 32-bit and 64-bit.


%package devel
Summary: Header files and libraries for developing apps which will use sqlite.
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: pkg-config

%description devel
The sqlite-devel package contains the header files and libraries needed
to develop programs that use the sqlite database library.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc -q64" or "gcc -maix64".


%prep
%setup -q


%build
# setup environment for 32-bit and 64-bit builds
export AR="ar -X32_64"
export NM="nm -X32_64"

# first build the 64-bit version
export CC="xlc -q64"
./configure \
    --prefix=%{_prefix} \
    --enable-shared --enable-static \
    --disable-tcl \
    --enable-threadsafe \
    --enable-threads-override-locks

# "correct" Makefile
cat Makefile | sed -e "s|THREADLIB|LIBPTHREAD|" > Makefile.tmp
mv Makefile.tmp Makefile

gmake %{?_smp_mflags}

cp .libs/libsqlite3.so.0 .
gmake distclean

# now build the 32-bit version
export CC="xlc"
./configure \
    --prefix=%{_prefix} \
    --enable-shared --enable-static \
    --disable-tcl \
    --enable-threadsafe \
    --enable-threads-override-locks

# "correct" Makefile
cat Makefile | sed -e "s|THREADLIB|LIBPTHREAD|" > Makefile.tmp
mv Makefile.tmp Makefile

gmake %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
gmake DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip ${RPM_BUILD_ROOT}%{_bindir}/* || :

# setup environment for 32-bit and 64-bit builds
export AR="ar -X32_64"

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
${AR} -q ${RPM_BUILD_ROOT}%{_libdir}/libsqlite3.a ./libsqlite3.so.0

mkdir -p ${RPM_BUILD_ROOT}%{_mandir}/man1/
cp sqlite3.1 ${RPM_BUILD_ROOT}%{_mandir}/man1
chmod 644 ${RPM_BUILD_ROOT}%{_mandir}/man1/*

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%doc README
%{_bindir}/*
%{_libdir}/*.a
%{_mandir}/man?/*
/usr/bin/*
/usr/lib/*.a


%files devel
%defattr(-,root,system)
%doc doc/
%{_includedir}/*
%{_libdir}/*.la
%{_libdir}/pkgconfig/*.pc
/usr/include/*
/usr/lib/*.la


%changelog
* Thu Aug 26 2010 Michael Perzl <michael@perzl.org> - 3.7.2-1
- updated to version 3.7.2

* Tue Aug 10 2010 Michael Perzl <michael@perzl.org> - 3.7.0.1-1
- updated to version 3.7.0.1

* Fri Jul 23 2010 Michael Perzl <michael@perzl.org> - 3.7.0-1
- updated to version 3.7.0

* Mon Apr 26 2010 Michael Perzl <michael@perzl.org> - 3.6.23.1-1
- updated to version 3.6.23.1

* Tue Mar 23 2010 Michael Perzl <michael@perzl.org> - 3.6.23-1
- updated to version 3.6.23

* Tue Jan 19 2010 Michael Perzl <michael@perzl.org> - 3.6.22-1
- updated to version 3.6.22

* Thu Dec 17 2009 Michael Perzl <michael@perzl.org> - 3.6.21-1
- updated to version 3.6.21

* Tue Nov 17 2009 Michael Perzl <michael@perzl.org> - 3.6.20-1
- updated to version 3.6.20

* Wed Aug 26 2009 Michael Perzl <michael@perzl.org> - 3.6.17-1
- updated to version 3.6.17

* Mon Apr 20 2009 Michael Perzl <michael@perzl.org> - 3.6.13-1
- updated to version 3.6.13

* Tue Feb 17 2009 Michael Perzl <michael@perzl.org> - 3.6.10-1
- updated to version 3.6.10

* Tue Jan 13 2009 Michael Perzl <michael@perzl.org> - 3.6.8-1
- updated to version 3.6.8

* Thu Oct 23 2008 Michael Perzl <michael@perzl.org> - 3.6.4-1
- updated to version 3.6.4

* Thu Aug 14 2008 Michael Perzl <michael@perzl.org> - 3.6.1-1
- updated to version 3.6.1

* Mon May 19 2008 Michael Perzl <michael@perzl.org> - 3.5.9-1
- updated to version 3.5.9

* Wed Apr 23 2008 Michael Perzl <michael@perzl.org> - 3.5.8-1
- updated to version 3.5.8

* Tue Apr 01 2008 Michael Perzl <michael@perzl.org> - 3.5.6-3
- linked against new version of readline

* Fri Mar 28 2008 Michael Perzl <michael@perzl.org> - 3.5.6-2
- corrected some SPEC file errors 

* Fri Feb 22 2008 Michael Perzl <michael@perzl.org> - 3.5.6-1
- updated to version 3.5.6

* Thu Jan 03 2008 Michael Perzl <michael@perzl.org> - 3.5.4-2
- included both 32-bit and 64-bit shared objects

* Tue Dec 18 2007 Michael Perzl <michael@perzl.org> - 3.5.4-1
- First version for AIX5L v5.1 and higher
